@@ -21,16 +21,17 @@
 #include <QObject>
 #include <QTime>
 #include <QUrl>
+#include <QColor>
 
 class Utils : public QObject
 {
     Q_OBJECT
 public:
-    explicit Utils(QObject* parent = 0);
-    Q_INVOKABLE QUrl findImage(const QString &name);
+    explicit Utils(QObject* parent = nullptr);
     Q_INVOKABLE int getMinutesOfQTime(const QTime& time);
     Q_INVOKABLE int getSecondsOfQTime(const QTime& time);
     Q_INVOKABLE QString uuid();
+    Q_INVOKABLE QColor alpha(const QColor& color, float alpha);
 
 };
 
