@@ -19,12 +19,11 @@
 #define LESSONPAINTER_H
 
 #include <QQuickPaintedItem>
-#include <QPixmap>
+#include <QImage>
 
 #include <QPointer>
 
 class QTextDocument;
-class QTextFrame;
 
 class Lesson;
 class TrainingLineCore;
@@ -60,7 +59,7 @@ signals:
     void cursorRectangleChanged();
     void done();
 protected:
-    void paint(QPainter* painter);
+    void paint(QPainter* painter) override;
 private slots:
     void updateLayout();
     void resetTrainingStatus();
@@ -78,7 +77,7 @@ private:
     qreal m_textScale;
     qreal m_maximumWidth;
     qreal m_maximumHeight;
-    QPixmap m_imageCache;
+    QImage m_imageCache;
     bool m_imageCacheDirty;
     TrainingLineCore* m_trainingLineCore;
     int m_currentLine;
