@@ -24,7 +24,6 @@ class QUndoGroup;
 class QTimer;
 class KAction;
 class KActionCollection;
-class KCategorizedView;
 class CategorizedResourceSortFilterProxyModel;
 class DataIndex;
 class ResourceModel;
@@ -39,7 +38,7 @@ public:
     virtual ~ResourceEditor();
 
 protected:
-    virtual void closeEvent(QCloseEvent* event);
+    void closeEvent(QCloseEvent* event) override;
 
 private slots:
     void newResource();
@@ -67,12 +66,12 @@ private:
     Resource* m_backupResource;
     QUndoGroup* m_undoGroup;
     KActionCollection* m_actionCollection;
-    KAction* m_newResourceAction;
-    KAction* m_deleteResourceAction;
-    KAction* m_undoAction;
-    KAction* m_redoAction;
-    KAction* m_importResourceAction;
-    KAction* m_exportResourceAction;
+    QAction* m_newResourceAction;
+    QAction* m_deleteResourceAction;
+    QAction* m_undoAction;
+    QAction* m_redoAction;
+    QAction* m_importResourceAction;
+    QAction* m_exportResourceAction;
     ResourceEditorWidget* m_editorWidget;
     QTimer* m_saveTimer;
 };
