@@ -26,6 +26,9 @@
 
 int main(int argc, char **argv)
 {
+    Application::setAttribute(Qt::AA_EnableHighDpiScaling);
+    Application::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
     Application app(argc, argv);
 
     KLocalizedString::setApplicationDomain("ktouch");
