@@ -68,7 +68,7 @@ void MainWindow::onViewStatusChanged(QQuickView::Status status)
         }
         QMessageBox qmlErrorMsgBox;
         qmlErrorMsgBox.setText(i18n("%1 has encountered a runtime error and has to be closed.", KAboutData::applicationData().displayName()));
-        qmlErrorMsgBox.setDetailedText(errorMessages.join(QStringLiteral("\n")));
+        qmlErrorMsgBox.setDetailedText(errorMessages.join(QLatin1Char('\n')));
         qmlErrorMsgBox.setStandardButtons(QMessageBox::Close);
         qmlErrorMsgBox.setIcon(QMessageBox::Critical);
         qmlErrorMsgBox.exec();
