@@ -18,11 +18,12 @@
 
 #include "categorizedresourcesortfilterproxymodel.h"
 
-#include "KStringHandler"
+#include <QCollator>
 
 CategorizedResourceSortFilterProxyModel::CategorizedResourceSortFilterProxyModel(QObject *parent) :
     KCategorizedSortFilterProxyModel(parent),
     m_resourceTypeFilter(ResourceModel::CourseItem | ResourceModel::KeyboardLayoutItem),
+    m_invertedKeyboardLayoutNameFilter(false),
     m_resourceModel(0)
 {
     setDynamicSortFilter(true);
@@ -62,10 +63,29 @@ void CategorizedResourceSortFilterProxyModel::setKeyboardLayoutNameFilter(const
     }
 }
 
+bool CategorizedResourceSortFilterProxyModel::invertedKeyboardLayoutNameFilter() const
+{
+    return m_invertedKeyboardLayoutNameFilter;
+}
+
+void CategorizedResourceSortFilterProxyModel::setInvertedKeyboardLayoutNameFilter(bool inverted)
+{
+    if (inverted != m_invertedKeyboardLayoutNameFilter)
+    {
+        m_invertedKeyboardLayoutNameFilter = inverted;
+        invalidateFilter();
+        invalidate();
+        sort(0);
+        emit invertedKeyboardLayoutNameFilterChanged();
+    }
+}
+
+
 ResourceModel* CategorizedResourceSortFilterProxyModel::resourceModel() const
 {
     return m_resourceModel;
 }
+
 void CategorizedResourceSortFilterProxyModel::setResourceModel(ResourceModel* resourceModel)
 {
     if (resourceModel != m_resourceModel)
@@ -81,7 +101,10 @@ bool CategorizedResourceSortFilterProxyModel::subSortLessThan(const QModelIndex&
 {
     const QString leftStr = sourceModel()->data(left, Qt::DisplayRole).toString();
     const QString rightStr = sourceModel()->data(right, Qt::DisplayRole).toString();
-    const int difference = KStringHandler::naturalCompare(leftStr, rightStr, Qt::CaseInsensitive);
+    QCollator locater;
+    locater.setCaseSensitivity(Qt::CaseInsensitive);
+
+    const int difference = locater.compare(leftStr, rightStr);
 
     if (difference == 0)
     {
@@ -104,5 +127,5 @@ bool CategorizedResourceSortFilterProxyModel::filterAcceptsRow(int source_row, c
 
     const QString name = sourceModel()->data(index, ResourceModel::KeyboardLayoutNameRole).toString();
 
-    return name == m_keyboardLayoutNameFilter;
+    return m_invertedKeyboardLayoutNameFilter ^ (name == m_keyboardLayoutNameFilter);
 }
