@@ -37,7 +37,7 @@ TrainingStats* ErrorsModel::trainingStats() const
 
 int ErrorsModel::maximumErrorCount() const
 {
-    if (m_errors.count() == 0)
+    if (m_errors.isEmpty())
         return 0;
 
     return m_errors.at(0).second;
@@ -138,7 +138,7 @@ void ErrorsModel::buildErrorList()
         m_errors.append(QPair<QString,int>(errorIterator.key(), errorIterator.value()));
     }
 
-    qSort(m_errors.begin(), m_errors.end(), lessThan);
+    std::sort(m_errors.begin(), m_errors.end(), lessThan);
 
     emit maximumErrorCountChanged();
 
